@@ -28,8 +28,11 @@ enum
 {
 	COL_CHECK,
 	COL_DEVICE,
+	COL_MOUNT_D,
 	COL_MOUNT,
 	COL_TYPE,
+	COL_FS_SIZE,
+	COL_FS_AVAIL,
 	TOT_COLUMNS
 };
 
