@@ -1,30 +1,48 @@
+/* screenshot-dialog.c - main GNOME Screenshot dialog
+ *
+ * Copyright (C) 2001-2006  Jonathan Blandford <jrb@alum.mit.edu>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ */
+
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
 
 #include "screenshot-dialog.h"
 #include "screenshot-save.h"
-#include <libgnomevfs/gnome-vfs.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 
 enum {
-  TYPE_IMAGE,
-  TYPE_URI,
+  TYPE_IMAGE_PNG,
+  TYPE_TEXT_URI_LIST,
+  
+  LAST_TYPE
 };
 
 static GtkTargetEntry drag_types[] =
 {
-  { "image/png", 0, TYPE_IMAGE },
-  { "x-special/gnome-icon-list", 0, TYPE_URI },
-  { "text/uri-list", 0, TYPE_URI }
+  { "image/png", 0, TYPE_IMAGE_PNG },
+  { "text/uri-list", 0, TYPE_TEXT_URI_LIST },
 };
 
 struct ScreenshotDialog
 {
-  GladeXML *xml;
+  GtkBuilder *ui;
   GdkPixbuf *screenshot;
   GdkPixbuf *preview_image;
   GtkWidget *save_widget;
@@ -145,22 +163,28 @@ drag_data_get (GtkWidget          *widget,
 	       GtkSelectionData   *selection_data,
 	       guint               info,
 	       guint               time,
-	       ScreenshotDialog *dialog)
+	       ScreenshotDialog   *dialog)
 {
-  if (info == TYPE_URI) {
-	char *string;
+  if (info == TYPE_TEXT_URI_LIST)
+    {
+      gchar **uris;
 
-	string = g_strdup_printf ("file:%s\r\n",
-				  screenshot_save_get_filename ());
-	gtk_selection_data_set (selection_data,
-				selection_data->target,
-				8, string, strlen (string)+1);
-	g_free (string);
-  } else if (info == TYPE_IMAGE) {
-	gtk_selection_data_set_pixbuf (selection_data, dialog->screenshot);
-  } else {
-	g_warning ("Unknown type %d", info);
-  }
+      uris = g_new (gchar *, 2);
+      uris[0] = g_strconcat ("file://",
+                             screenshot_save_get_filename (),
+                             NULL);
+      uris[1] = NULL;
+      
+      gtk_selection_data_set_uris (selection_data, uris);
+    }
+  else if (info == TYPE_IMAGE_PNG)
+    {
+      gtk_selection_data_set_pixbuf (selection_data, dialog->screenshot);
+    }
+  else
+    {
+      g_warning ("Unknown type %d", info);
+    }
 }
 
 static void
@@ -188,46 +212,50 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
   char *current_name;
   char *ext;
   gint pos;
-  GnomeVFSURI *tmp_uri;
-  GnomeVFSURI *parent_uri;
+  GFile *tmp_file;
+  GFile *parent_file;
+  guint res;
 
-  tmp_uri = gnome_vfs_uri_new (initial_uri);
-  parent_uri = gnome_vfs_uri_get_parent (tmp_uri);
+  tmp_file = g_file_new_for_uri (initial_uri);
+  parent_file = g_file_get_parent (tmp_file);
 
-  current_name = gnome_vfs_uri_extract_short_name (tmp_uri);
-  current_folder = gnome_vfs_uri_to_string (parent_uri, GNOME_VFS_URI_HIDE_NONE);
-  gnome_vfs_uri_unref (tmp_uri);
-  gnome_vfs_uri_unref (parent_uri);
+  current_name = g_file_get_basename (tmp_file);
+  current_folder = g_file_get_uri (parent_file);
+  g_object_unref (tmp_file);
+  g_object_unref (parent_file);
 
   dialog = g_new0 (ScreenshotDialog, 1);
 
-  dialog->xml = glade_xml_new (GLADEDIR "/gnome-screenshot.glade", NULL, NULL);
+  dialog-> ui = gtk_builder_new ();
+  res = gtk_builder_add_from_file (dialog->ui, UIDIR "/gnome-screenshot.ui", NULL);
   dialog->screenshot = screenshot;
 
-  if (dialog->xml == NULL)
+  if (res == 0)
     {
       GtkWidget *dialog;
       dialog = gtk_message_dialog_new (NULL, 0,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
-				       _("Glade file for the screenshot program is missing.\n"
+				       _("UI definition file for the screenshot program is missing.\n"
 					 "Please check your installation of gnome-utils"));
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       exit (1);
     }
 
+  gtk_builder_set_translation_domain (dialog->ui, GETTEXT_PACKAGE);
+
   width = gdk_pixbuf_get_width (screenshot);
   height = gdk_pixbuf_get_height (screenshot);
 
   width /= 5;
   height /= 5;
 
-  toplevel = glade_xml_get_widget (dialog->xml, "toplevel");
-  aspect_frame = glade_xml_get_widget (dialog->xml, "aspect_frame");
-  preview_darea = glade_xml_get_widget (dialog->xml, "preview_darea");
-  dialog->filename_entry = glade_xml_get_widget (dialog->xml, "filename_entry");
-  file_chooser_box = glade_xml_get_widget (dialog->xml, "file_chooser_box");
+  toplevel = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "toplevel"));
+  aspect_frame = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "aspect_frame"));
+  preview_darea = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "preview_darea"));
+  dialog->filename_entry = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "filename_entry"));
+  file_chooser_box = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "file_chooser_box"));
 
   dialog->save_widget = gtk_file_chooser_button_new (_("Select a folder"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
   gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog->save_widget), FALSE);
@@ -279,6 +307,12 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
   return dialog;
 }
 
+void
+screenshot_dialog_focus_entry (ScreenshotDialog *dialog)
+{
+  gtk_widget_grab_focus (dialog->filename_entry);
+}
+
 void
 screenshot_dialog_enable_dnd (ScreenshotDialog *dialog)
 {
@@ -286,9 +320,9 @@ screenshot_dialog_enable_dnd (ScreenshotDialog *dialog)
 
   g_return_if_fail (dialog != NULL);
 
-  preview_darea = glade_xml_get_widget (dialog->xml, "preview_darea");
+  preview_darea = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "preview_darea"));
   gtk_drag_source_set (preview_darea,
-		       GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
+		       GDK_BUTTON1_MASK | GDK_BUTTON3_MASK,
 		       drag_types, G_N_ELEMENTS (drag_types),
 		       GDK_ACTION_COPY);
 }
@@ -296,7 +330,7 @@ screenshot_dialog_enable_dnd (ScreenshotDialog *dialog)
 GtkWidget *
 screenshot_dialog_get_toplevel (ScreenshotDialog *dialog)
 {
-  return glade_xml_get_widget (dialog->xml, "toplevel");
+  return GTK_WIDGET (gtk_builder_get_object (dialog->ui, "toplevel"));
 }
 
 char *
@@ -305,13 +339,26 @@ screenshot_dialog_get_uri (ScreenshotDialog *dialog)
   gchar *folder;
   const gchar *file_name;
   gchar *uri, *file, *tmp;
+  GError *error;
 
   folder = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (dialog->save_widget));
   file_name = gtk_entry_get_text (GTK_ENTRY (dialog->filename_entry));
 
-  tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, NULL);
-  file = gnome_vfs_escape_host_and_path_string (tmp);
+  error = NULL;
+  tmp = g_filename_from_utf8 (file_name, -1, NULL, NULL, &error);
+  if (error)
+    {
+      g_warning ("Unable to convert `%s' to valid UTF-8: %s\n"
+                 "Falling back to default file.",
+                 file_name,
+                 error->message);
+      g_error_free (error);
+      tmp = g_strdup (_("Screenshot.png"));
+    }
+
+  file = g_uri_escape_string (tmp, NULL, FALSE);
   uri = g_build_filename (folder, file, NULL);
+
   g_free (folder);
   g_free (tmp);
   g_free (file);
@@ -324,6 +371,13 @@ screenshot_dialog_get_folder (ScreenshotDialog *dialog)
 {
   return gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (dialog->save_widget));
 }
+
+GdkPixbuf *
+screenshot_dialog_get_screenshot (ScreenshotDialog *dialog)
+{
+  return dialog->screenshot;
+}
+
 void
 screenshot_dialog_set_busy (ScreenshotDialog *dialog,
 			    gboolean          busy)
