@@ -796,7 +796,7 @@ move_to_trash_cb (GtkAction * action,
 		GtkTreeIter iter;
 		GList * list;
 		GFile * g_file;
-		GError * error;
+		GError * error = NULL;
 		gchar * utf8_basename;
 		gchar * utf8_filename;
 		gchar * locale_filename;
@@ -851,7 +851,7 @@ move_to_trash_cb (GtkAction * action,
 
 			if (response == GTK_RESPONSE_OK) {
 				GFile * g_file_tmp;
-				GError * error_tmp;
+				GError * error_tmp = NULL;
 
 				g_file_tmp = g_file_new_for_path (locale_filename);
 				result = g_file_delete (g_file_tmp, NULL, &error_tmp);
@@ -1060,7 +1060,7 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 			}
 		
 			/* Popup menu item: Open with (default) */
-			str = g_strdup_printf ("_Open with \"%s\"",  g_app_info_get_name (list->data));
+			str = g_strdup_printf (_("_Open with %s"),  g_app_info_get_name (list->data));
 			new1 = gtk_image_menu_item_new_with_mnemonic (str);
 			gtk_widget_show (new1);
 
@@ -1071,17 +1071,20 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 			g_signal_connect ((gpointer) new1, "activate", G_CALLBACK (open_file_cb),
 					  (gpointer) gsearch);
 
-			file_icon = g_object_ref (g_app_info_get_icon ((GAppInfo *)list->data));
+			if (g_app_info_get_icon ((GAppInfo *)list->data) != NULL) {
+				file_icon = g_object_ref (g_app_info_get_icon ((GAppInfo *)list->data));
+				gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (new1), file_icon != NULL);
 
-			if (file_icon == NULL) {
-				file_icon = g_themed_icon_new (GTK_STOCK_OPEN);
+				if (file_icon == NULL) {
+					file_icon = g_themed_icon_new (GTK_STOCK_OPEN);
+				}
+
+				image1 = gtk_image_new_from_gicon (file_icon, GTK_ICON_SIZE_MENU);
+				g_object_unref (file_icon);
+				gtk_widget_show (image1);
+				gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (new1), image1);
 			}
-
-			image1 = gtk_image_new_from_gicon (file_icon, GTK_ICON_SIZE_MENU);
-			g_object_unref (file_icon);
-			gtk_widget_show (image1);
-			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (new1), image1);
-		
+			
 			separatormenuitem1 = gtk_separator_menu_item_new ();
 			gtk_widget_show (separatormenuitem1);
 			gtk_container_add (GTK_CONTAINER (gsearch->search_results_popup_menu), separatormenuitem1);
@@ -1090,8 +1093,14 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 			for (list = g_list_next (list), i = 0; list != NULL; list = g_list_next (list), i++) {
 
 				/* Popup menu item: Open with (others) */
-				str = g_strdup_printf ("Open with \"%s\"",  g_app_info_get_name (list->data));
-				new1 = gtk_menu_item_new_with_mnemonic (str);
+				if (list_length < 4) {
+					str = g_strdup_printf (_("Open with %s"),  g_app_info_get_name (list->data));
+				}
+				else {
+					str = g_strdup_printf ("%s",  g_app_info_get_name (list->data));
+				}
+				
+				new1 = gtk_image_menu_item_new_with_mnemonic (str);
 				gtk_widget_show (new1);
 
 				g_object_set_data_full (G_OBJECT (new1), "app", (GAppInfo *)list->data,
@@ -1099,6 +1108,20 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 
 				if (list_length >= 4) {
 
+					if (g_app_info_get_icon ((GAppInfo *)list->data) != NULL) {
+						file_icon = g_object_ref (g_app_info_get_icon ((GAppInfo *)list->data));
+						gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (new1), file_icon != NULL);
+
+						if (file_icon == NULL) {
+							file_icon = g_themed_icon_new (GTK_STOCK_OPEN);
+						}
+				
+						image1 = gtk_image_new_from_gicon (file_icon, GTK_ICON_SIZE_MENU);
+						g_object_unref (file_icon);
+						gtk_widget_show (image1);
+						gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (new1), image1);
+					}
+					
 					if (i == 0) {
 						gsearch->search_results_popup_submenu = gtk_menu_new ();
 
@@ -1119,6 +1142,20 @@ build_popup_menu_for_file (GSearchWindow * gsearch,
 					                  (gpointer) gsearch);
 				}
 				else {
+					if (g_app_info_get_icon ((GAppInfo *)list->data) != NULL) {
+
+						file_icon = g_object_ref (g_app_info_get_icon ((GAppInfo *)list->data));
+						gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (new1), file_icon != NULL);
+
+						if (file_icon == NULL) {
+							file_icon = g_themed_icon_new (GTK_STOCK_OPEN);
+						}
+				
+						image1 = gtk_image_new_from_gicon (file_icon, GTK_ICON_SIZE_MENU);
+						g_object_unref (file_icon);
+						gtk_widget_show (image1);
+						gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (new1), image1);
+					}
 					gtk_container_add (GTK_CONTAINER (gsearch->search_results_popup_menu), new1);
 					g_signal_connect ((gpointer) new1, "activate", G_CALLBACK (open_file_cb),
 					                  (gpointer) gsearch);
