@@ -35,8 +35,6 @@
 #include "logview-manager.h"
 #include "logview-filter-manager.h"
 
-#include "gtkmessagearea.h"
-
 #define APP_NAME _("System Log Viewer")
 #define SEARCH_START_MARK "lw-search-start-mark"
 #define SEARCH_END_MARK "lw-search-end-mark"
@@ -84,7 +82,7 @@ static void findbar_close_cb  (LogviewFindbar *findbar,
 static void read_new_lines_cb (LogviewLog *log,
                                const char **lines,
                                GSList *new_days,
-                               GError **error,
+                               GError *error,
                                gpointer user_data);
 
 /* private functions */
@@ -244,7 +242,7 @@ logview_set_font (LogviewWindow *logview,
 }
 
 static void
-logview_set_fontsize (LogviewWindow *logview)
+logview_set_fontsize (LogviewWindow *logview, gboolean store)
 {
   PangoFontDescription *fontdesc;
   PangoContext *context;
@@ -255,7 +253,9 @@ logview_set_fontsize (LogviewWindow *logview)
   pango_font_description_set_size (fontdesc, (priv->fontsize) * PANGO_SCALE);
   gtk_widget_modify_font (priv->text_view, fontdesc);
 
-  logview_prefs_store_fontsize (logview->priv->prefs, priv->fontsize);
+  if (store) {
+    logview_prefs_store_fontsize (logview->priv->prefs, priv->fontsize);
+  }
 }
 
 static void
@@ -388,21 +388,21 @@ static void
 logview_bigger_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MIN (logview->priv->fontsize + 1, 24);
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }	
 
 static void
 logview_smaller_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MAX (logview->priv->fontsize-1, 6);
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }	
 
 static void
 logview_normal_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = logview->priv->original_fontsize;
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }
 
 static void
@@ -998,7 +998,7 @@ static void
 read_new_lines_cb (LogviewLog *log,
                    const char **lines,
                    GSList *new_days,
-                   GError **error,
+                   GError *error,
                    gpointer user_data)
 {
   LogviewWindow *window = user_data;
@@ -1007,9 +1007,26 @@ read_new_lines_cb (LogviewLog *log,
   int i, old_line_count, filter_start_line;
   GtkTextIter iter, start;
   GtkTextMark *mark;
-  char *converted;
+  char *converted, *primary;
   gsize len;
 
+  if (error != NULL) {
+    /* no new strings in the primary error message,
+     * as we're string frozen
+     */
+    primary = g_strdup_printf ("\"%s\":",
+                               logview_log_get_display_name (log));
+    logview_window_add_error (window, primary, error->message);
+    g_free (primary);
+
+    return;
+  }
+
+  if (lines == NULL) {
+    /* there's no error, but no lines have been read */
+    return;
+  }
+
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (window->priv->text_view));
   old_line_count = gtk_text_buffer_get_line_count (buffer);
   filter_start_line = old_line_count > 0 ? (old_line_count - 1) : 0;
@@ -1232,8 +1249,10 @@ message_area_create_error_box (LogviewWindow *window,
 
   window->priv->message_secondary = secondary_label;
 
-  gtk_message_area_set_contents (GTK_MESSAGE_AREA (message_area),
-                                 hbox_content);
+  gtk_container_add
+      (GTK_CONTAINER (gtk_info_bar_get_content_area
+                      (GTK_INFO_BAR (message_area))),
+       hbox_content);
 }
 
 static void
@@ -1257,7 +1276,7 @@ message_area_set_labels (LogviewWindow *window,
 }
 
 static void
-message_area_response_cb (GtkMessageArea *message_area,
+message_area_response_cb (GtkInfoBar *message_area,
                           int response_id, gpointer user_data)
 {
   LogviewWindow *window = user_data;
@@ -1369,11 +1388,10 @@ logview_window_init (LogviewWindow *logview)
   gtk_paned_pack2 (GTK_PANED (hpaned), main_view, TRUE, TRUE);
 
   /* second pane: error message area */
-  priv->message_area = gtk_message_area_new ();
+  priv->message_area = gtk_info_bar_new ();
   message_area_create_error_box (logview, priv->message_area);
-  gtk_message_area_add_stock_button_with_text (GTK_MESSAGE_AREA (priv->message_area),
-                                               _("Close"), GTK_STOCK_CLOSE,
-                                               GTK_RESPONSE_CLOSE);
+  gtk_info_bar_add_button (GTK_INFO_BAR (priv->message_area),
+                           GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
   gtk_box_pack_start (GTK_BOX (main_view), priv->message_area, FALSE, FALSE, 0);
 
   /* second pane: text view */
@@ -1404,7 +1422,13 @@ logview_window_init (LogviewWindow *logview)
 
   /* restore saved zoom */
   priv->fontsize = logview_prefs_get_stored_fontsize (priv->prefs);
-  logview_set_fontsize (logview);
+
+  if (priv->fontsize <= 0) {
+    /* restore the default */
+    logview_normal_text (NULL, logview);
+  } else {
+    logview_set_fontsize (logview, FALSE);
+  }
 
   /* version selector */
   priv->version_bar = gtk_hbox_new (FALSE, 0);
